@@ -58,7 +58,7 @@ module gaussian_charges
 
   private
 
-  integer, parameter  :: GAUSSIAN_CHARGES_MAX_EL  = 3
+  integer, parameter  :: GAUSSIAN_CHARGES_MAX_EL  = 16
 
   !
   ! The module for the computation of energies/potentials
@@ -67,7 +67,7 @@ module gaussian_charges
   type gaussian_charges_db_t
 
      integer   :: nel = -1
-     integer   :: nU
+     integer   :: nU = -1
 
      character :: el(2, GAUSSIAN_CHARGES_MAX_EL)   !< Atom type
 
